@@ -8,5 +8,6 @@ system_check <- function(cmd) {
 
 R <- function(options, path = tempdir()) {
   r_path <- shQuote(file.path(R.home("bin"), "R"))
-  in_dir(path, system_check(paste(r_path, options)))
-}
\ No newline at end of file
+  options <- paste(options, collapse = " ")
+  in_dir(path, system_check(paste("LC_ALL=C", r_path, options)))
+}
